==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicColorChooserUI__24PropertyHandler.h <==
// public class javax.swing.plaf.basic.BasicColorChooserUI$PropertyHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3176613dc16d6831 javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$method$_init$5fea946ba5b0bc9f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *);

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods	javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs	javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object {
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/basic/BasicColorChooserUI__24PropertyHandler.h <==
// public class javax.swing.plaf.basic.BasicColorChooserUI$PropertyHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 77c58ec485c77c2d javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler_H_
#define _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler_H_

// Forward structure declarations
struct _jc_java_beans_PropertyChangeEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$method$_init$5fea946ba5b0bc9f(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$method$propertyChange$6d3500eaa79bf44b(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$method_info$propertyChange$6d3500eaa79bf44b;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods {
	void	(*propertyChange$6d3500eaa79bf44b)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object *, struct _jc_java_beans_PropertyChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vmethods	javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs {
	struct _jc_javax_swing_plaf_basic_BasicColorChooserUI$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs {
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_refs	javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$sub_nonrefs	javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$object {
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$vtype _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicColorChooserUI__24PropertyHandler_H_ */
